/* COOKIE : functions
 * 
 * the strtr in the cookie functions is NOT encryption. SSL is
 * relied on for the encryption - if you do not use SSL, NONE of this is
 * secure. this is just in case cookie values get displayed on the screen,
 * or something similar. If someone has a better way, please let me know.
 */
/* String translations for "data spooging within the cookie functions */
$trans_fwd = ' abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890~!@#$%^&*()_+=-';
$trans_bck = '1234567890-=ABCDEFGHIJKLMNOPQRSTUVWXYZ~!@#$%^&*()_+abcdefghijklm nopqrstuvwxyz';
