<br>
<b>Sort options :</b>
<center>

<a href="mailbox.php3?mailbox=<?php echo urlencode($mailbox) ?>&sortby=<?php echo SORTDATE ?>&sort_reverse=<?php echo $sort_reverse ?>"><?php echo $lang->sort_by_label . ' ( ' . $lang->date_label . ' ) '; ?></a>

<a href="mailbox.php3?mailbox=<?php echo urlencode($mailbox) ?>&status=green&sortby=<?php echo SORTFROM ?>&sort_reverse=<?php echo $sort_reverse ?>"><?php echo $lang->sort_by_label . ' ( ' . $lang->from_label . ' ) '; ?></a>
    
<a href="mailbox.php3?mailbox=<?php echo urlencode($mailbox) ?>&status=green&sortby=<?php echo SORTSUBJECT ?>&sort_reverse=<?php echo $sort_reverse ?>"><?php echo $lang->sort_by_label . ' ( ' . $lang->subject_label . ' ) '; ?></font></a>

<a href="mailbox.php3?mailbox=<?php echo urlencode($mailbox) ?>&status=green&sortby=<?php echo SORTSIZE ?>&sort_reverse=<?php echo $sort_reverse ?>"><?php echo $lang->sort_by_label . ' ( ' . $lang->size_label . ' ) '; ?></a>
</center>
<br>
