<table border="0" align="center" width="95%" cellpadding="3" cellspacing="0">
<form method=post name="delete">
<input type="hidden" name="actionID" value="<?php echo DELETE_FOLDER ?>">

<tr bgcolor="<?php echo $default->dark_bg ?>">
  <td colspan="2" align="left">
    <?php $default->text_on_dark->start(); ?><b><?php echo $lang->delete_label ?></b></font>
  </td>
<td align="right"><?php $help->link(FOLDERS_HELP_DELETE, $help_file, 'imp') ?></td>
</tr>
<tr>
  <td align="right"><?php echo $lang->delete ?></td>
  <td colspan="2" align="left" bgcolor="<?php echo $default->item_bg ?>" width="100%">
    <select name="dead_mailbox"><?php echo "\n" . $newlist ?>
    </select>
  </td>
</tr>
<tr><td colspan="3" align="center"><input type="submit" value="<?php echo $lang->delete_button ?>" onclick="return verifyDelete();"></td></tr>

</form>
</table>

<script language="Javascript">
<!--
function verifyDelete () {
   return confirm("<?php echo $lang->confirm_delete ?>");
}
// -->
</script>
