<?php
/*
Load this post defaults.php3
*/
// $default->deleted_flag              = 'D';
// $default->unread_flag               = 'N';
// $default->answered_flag             = 'A';

$default->deleted_flag              = '<img alt="[deleted]" src="graphics/deleted.gif">';
$default->unread_flag               = '<img alt="[unread]" src="graphics/newmail.gif">';
$default->answered_flag             = '<img alt="[answered]" src="graphics/answered.gif">';

/* attributes for mailbox pages */
$default->max_frm_chars             = 40;
$default->max_sub_chars             = 50;
$default->max_messages_page         = 30;
$default->fetch_mime_info           = true;    /* change to false for speed increase with mailbox.php3 */

/* sort order. can be one of:
 * SORTARRIVAL
 * SORTDATE
 * SORTFROM
 * SORTSUBJECT
 * SORTSIZE
 */
$default->sort_crit = SORTARRIVAL;
$default->sort_dir  = 0; // 0 = regular direction, 1 = last/highest first

?>
