<script language="JavaScript">
<!--

function Transfer(actID, form) {
  if (form == 1) {
    document.messages.targetMbox.value = document.messages.target1.options[document.messages.target1.selectedIndex].value;
  } else {
    document.messages.targetMbox.value = document.messages.target2.options[document.messages.target2.selectedIndex].value;
  }
  
  document.messages.actionID.value = actID;
  document.messages.submit();
}

function Submit(actID) {
  document.messages.actionID.value = actID;
  document.messages.submit();
}

function ToggleAll(checked) {
  len = document.messages.elements.length;
  var i=0;
  for(i=0; i < len; i++) {
    document.messages.elements[i].checked=checked;
  }
}

//-->
</script>
