<?php

/*
 
 File: config/ldap.php3
 $Author: cb13104 $
 $Revision: 1.6 $
 $Date: 1999/01/08 17:44:46 $
 
 IMP: Copywrite 1998 Charles J. Hagenbuch chuck@horde.org
 
 This code is under the GNU Public License
 See the file COPYING in this directory
 
 */
$LDAPServers = array();


$LDAPServers['four11'] = new LDAPServer('four11',
					'Four 11',
					'ldap.four11.com',
					'',
					'sn',
					'cn,mail,sn,givenname',
					'is,is_strict,contains,begins,ends');

$LDAPServers['infospace'] = new LDAPServer('infospace',
					   'Infospace',
					   'ldap.infospace.com',
					   '',
					   'sn',
					   'cn,mail,sn',
					   'is,is_strict,contains,begins,ends');

$LDAPServers['bigfoot'] = new LDAPServer('bigfoot',
					 'Bigfoot',
					 'ldap.bigfoot.com',
					 '',
					 'surname',
					 'cn,mail,sn',
					 'is,sounds,is_strict,contains,begins,ends');


$LDAPServers['infospacebiz'] = new LDAPServer('infospacebiz',
                                              'InfoSpace Business',
                                              'ldapbiz.infospace.com',
                                              '',
                                              'sn',
                                              'cn,sn',
                                              'is_strict,begins');



/* 
   The following is another example how to add your local LDAP server.
   Have a look at the last but one and the last line:
   The last but one specifies your domain (ie. o=[domain].
   The last line specifies the country (ie. c=[country].
   See horde lib for a complete list of options
*/

/*
$LDAPServers['uibk'] = new LDAPServer('uibk',
				      'Innsbruck',
				      'ldap.uibk.ac.at',
				      '',
				      'sn',
				      'cn,mail,sn,givenname,uid,ou',
				      'is,sounds,is_strict,contains,begins,ends',
				      'Universitaet Innsbruck',
				      'AT');
*/

?>
