/*
 
 $Author: mhardy $
 $Revision: 1.5 $
 $Date: 1999/03/25 21:18:00 $
 
 IMP: Copyright 1998 Charles J. Hagenbuch chuck@horde.org
 
 You should have received a copy of the GNU Public
 License along with this package; if not, write to the
 Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.
 
 
 File Purpose:
 This file contains the base classes and their descendents for 
 the interoperability of the horde. 
 
 AUTHORS NOTE :
 Please note that this file is autogenerated and is a collected library
 of the individual classes, functions, and other various code snippets.
 If you would like to edit this library please edit the appropriate file
 under the src subtree.
 
 */
