<?php
/*
The Actual calls to element includes and such are contained within
functions to prevent varaible collision in the main namespace.
*/
Function print_form() {
global $default;

$value      = $default->append_header;
$desc_text  = 'Prepend Header';
$name       = 'append_header';
$desc       = 'Prepends config/header.txt to every outgoing message.';
include( './templates/setup/form_true_false_elem.inc' ); 

$value      = $default->append_trailer;
$desc_text  = 'Append Trailer';
$name       = 'append_trailer';
$desc       = 'Appends config/trailer.txt to every outgoing message.';
include( './templates/setup/form_true_false_elem.inc' ); 

$value      = $default->text_parts_inline;
$desc_text  = 'View MIME text';
$name       = 'text_parts_inline';
$desc       = 'View MIME text parts in main window.';
include( './templates/setup/form_true_false_elem.inc' );



}

$form_subtitle = 'Message Configuration';
include( './templates/setup/stub_form.inc' );

?>
