<html>
<head>
<title><?php echo $lang->select_title ?></title>
</head>

<?php $default->sidebar->generate_body() ?>

<table border=0 cellpadding=0 cellspacing=0><tr><td bgcolor="<?php echo $default->dark_bg ?>">
<font size=2 face="<?php echo $default->text_on_dark->face; ?>" color="<?php echo $default->text_on_dark->color; ?>">
