<?php
/*
The Actual calls to element includes and such are contained within
functions to prevent varaible collision in the main namespace.
*/
Function print_form() {
global $default;


$value      = $default->lang;
$desc_text  = 'Default Language Type';
$name       = 'lang';
$desc       = '';

$possible         = Array();
$possible_vals    = Array();

$possible[]       = 'Czech';
$possible_vals[]  = 'cs';
$possible[]       = 'Danish';
$possible_vals[]  = 'da';
$possible[]       = 'German';
$possible_vals[]  = 'de';
$possible[]       = 'English';
$possible_vals[]  = 'en';
$possible[]       = 'Spanish';
$possible_vals[]  = 'es';
$possible[]       = 'French';
$possible_vals[]  = 'fr';
$possible[]       = 'Norwegian';
$possible_vals[]  = 'no';
$possible[]       = 'Brazilian Portugese';
$possible_vals[]  = 'pt-BR';
$possible[]       = 'Russian';
$possible_vals[]  = 'ru';
$possible[]       = 'Swedish';
$possible_vals[]  = 'sv';

include( './templates/setup/form_multiselect_elem.inc' ); 

}


$form_subtitle = 'Language Configuration';
include( './templates/setup/stub_form.inc' );

?>
