<html>
<head>
<?php if (isset($title)) echo "<title>$title</title>"; ?>
<?php $help->print_help_js() # Setup a help instance ?>
<script language="JavaScript">
<!-- Reload the folder select so the folder list is accurate
if (parent.impfolder) {
   parent.impfolder.location="select.php3";
}
//-->
</script>

</head>

<?php

$default->body->generate_body();

if (isset($default->enable_haiku) && $default->enable_haiku) {
   require ("./locale/$language/haiku.lang");
   echo '<p align="center"><i>';
   echo $haiku->folders;
   echo '</i></p>';
}
?>
