<table border="0" align="center" width="95%"><tr><td colspan=2>
<font size=1>&nbsp;</font>
</td></tr>
<tr><td colspan=2 bgcolor="<?php echo $default->text_bg ?>">
<pre>
<?php echo $msg ?>
</pre>
</td></tr>
</table>
