<center>
<h3>IMP - ERROR : IMP NOT CONFIGURED</h3>
</center>

<p>
You need to create the ./config/defaults.php3 file using one of the examples found within the ./config/examples directory, or from scratch using the documentation.

<br>
You can also use the imp setup wizard. In order to use the setup wizard you will need to enable write privlages to your configuration files by running the following command :

<ul>
   <li>UN*X Peoples : <br><br>
      cd your install directory here<br>
      sh ./install.sh
      <br><br>
   <li>Nt, Win95, etc... Install.pl does NOT work for you, and neither does the configuration wizard. So, you will need to goto ( TBD ) to get a zip file of the config and such created for you.
</ul>

</p>
