<?php
include( './templates/setup/form_header.inc' );
?>

<center>
   <form method="post" action="setup.php3">
   <?php hidden_elems( $form_next ); ?>
   <table cellspacing="0" border="1"> 

   <tr bgcolor="<?php echo( $default->dark_bg ); ?>">
      <td align="left">
       <img src="./graphics/impsmall.gif" alt="IMP">
      </td>
      <td align="right">
      <font color="<?php echo $default->text_on_dark->color; ?>">
      <h3><?php echo( $form_title ); ?></h3>
      </td>
   </tr>

   <tr bgcolor="<?php echo $default->item_bg; ?>">
      <td colspan="2">
      <font size=+1><b><?php echo( $form_subtitle ); ?> :</b></font>
      </td>
   </tr>

   <?php print_form(); ?>    

   <tr bgcolor="<?php echo $default->item_bg; ?>">
      <td colspan="2">
      <center>
      <b>
          <?php 
            if ( $form_next != IMP_SETUP_WIZ_STEP_2 ) {
            echo( '<input type="submit"    name="go" value="&lt-- Back">' );
            }
         ?>
         <input type="reset"     value="Reset Form">
         <input type="submit"    name="go" value="Next --&gt;">
         </form>
      </b>
      </center>
      </td>
   </tr>
   </table>
</center>
<?php
include( './templates/setup/form_footer.inc' );
?>
