<center>
<h3>IMP - ERROR : IMP LIB NOT CONFIGURED</h3>
</center>

<p>
You need to create the ./lib/ structure to use imp. <br>
   To do this :<br>
   <ul>
      <li>cd into the imp root
      <li>cd core/src
      <li>./buildlib --imp --with-(database options i.e. mysql) --with-session<br>
      e.x.<br>
     ./buildlib --imp --with-mysql --with-session
   </ul>
</p>
