#!/bin/sh

touch config/defaults.php3
touch ../lib/horde.lib
touch lib/db.lib
touch lib/imp.lib
touch ../lib/mime.lib
touch lib/mimetypes.lib

chmod 777 config/defaults.php3
chmod 777 ../lib/horde.lib
chmod 777 lib/db.lib
chmod 777 lib/imp.lib
chmod 777 ../lib/mime.lib
chmod 777 lib/mimetypes.lib

chmod 555 setup.php3

echo 
echo Your blank configuration file has been created, please go to the
echo configuration utitlity at :
echo     your install path url/imp/setup.php3
echo 
