/*
Table Structure for Oracle version

   (see scripts/oracle_create.sql)
   
   Preferences Table:

    field:     type:      	description:

    username   varchar2(255)	joe@imap.doe.com format username
    sig	       varchar2(2000)	signature
    fullname   varchar2(70)	Joe Doe
    replyto    varchar2(70)	joe@doe.com from and replyto address
    lang       varchar2(30)	users's preferred language (en, es, ...)
    (possibly more to be added later)
 
   Address Table:

    field:     type:          description:

    username   varchar2(255)  joe@doe.com identifier of who this entry belongs to
    address    varchar2(255)  address@mail.server.com - the actual address
    nickname   varchar2(255)  any entered nickname - ie "bonnie".
    fullname   varchar2(255)  full name - "My Bonnie".

*/
