<p><table border="0" align="center" width="95%" cellpadding="3">
<input type="hidden" name="old_fullname" value="<?php echo imp_get_fullname($user, $server) ?>">

<tr>
  <td colspan="2" bgcolor="<?php echo $default->dark_bg ?>" align="left">
    <?php $default->text_on_dark->start(); ?><b><?php echo $lang->edit_fullname ?></b></font>
  </td>
</tr>
<tr>
  <td colspan="2" bgcolor="<?php echo $default->item_bg ?>">
    <input type="text" name="fullname" size="60" value="<?php echo imp_get_fullname($user, $server) ?>"></td>
  </td>
</tr>
</table>
