<b><?php echo $ACTION_TEXT ?></b>
<br>
<br>

<form method="post" name="compose">

<input type="hidden" name="mailbox" value="<?php echo $mailbox ?>">
<?php if (isset($actionID) && (($actionID == REPLY) || ($actionID == REPLY_ALL))): ?>
<input type="hidden" name="is_reply" value="1">
<input type="hidden" name="in_reply_to" value="<?php echo $in_reply_to ?>">
<input type="hidden" name="references" value="<?php echo $references ?>">
<input type="hidden" name="index" value="<?php echo $index ?>">
<?php endif; ?>
<input notab type="hidden" name="actionID" value="">
<input type="hidden" name="attachmentAction" value="">

<?php if ($default->user_change_from): ?>
   <b><?php echo $lang->from_string ?></b>
   <input type="text" size="50" tabindex="1" name="from" value="<?php echo $from ?>">
   <br>
<?php endif; ?>

   <b><?php echo $lang->to_string ?></b>
   <input type="text" size="50" tabindex="2" name="to" onBlur="expand_to()" value="<?php echo $to ?>">
   <br>

   <b><?php echo $lang->cc_string ?></b>
   <input type="text" size="50" tabindex="3" name="cc" onBlur="expand_cc()" value="<?php echo $cc ?>">
   <br>

   <b><?php echo $lang->bcc_string ?></b>
   <input type="text" size="50" tabindex="3" name="bcc" onBlur="expand_bcc()" value="<?php echo $bcc ?>">
   <br>


   <b><?php echo $lang->subject_string ?></b>
   <input type="text" tabindex="4" name="subject" value="<?php echo $subject ?>" size="50">
   <br>


   <?php
   /*
   Lynx does not support file upload. 
    
   <b><?php echo $lang->attach_string ?></b>
   <input name="file_upload" type="file" size=48>
   <input notab type="submit" name="actionID" value="<?php echo $lang->button_attach ?>" onClick="attachmentAction.value = 'add'"></td>
</tr>

<?php if (count ($attachments_name) > 0): ?>

<tr>
  <td align="right" bgcolor="<?php echo $default->light_bg ?>"><?php $default->text_on_light->start(); ?><?php echo $lang->attach_string_plural ?></font></td>
  <td colspan="2" align="center" bgcolor="<?php echo $default->item_bg ?>">
  <div align="center">
  <table border="0" cellpadding="1" cellspacing="2" width="100%">
  <tr>
     <td bgcolor="#ddddaa" align="center"><input type="submit" name="actionID" value="<?php echo $lang->button_delete_attach ?>" onClick="attachmentAction.value = 'delete'"></td>
     <td bgcolor="#ddddaa" width="50%" align="left"><?php echo $lang->file_name ?></td>
     <td bgcolor="#ddddaa" width="50%" align="left"><?php echo $lang->file_size ?></td>
  </tr>
  <?php for ($i = 0; $i < count($attachments_name); $i++) { ?>
     <input type="hidden" name="attachments_name[]" value="<?php echo $attachments_name[$i] ?>">
     <input type="hidden" name="attachments_size[]" value="<?php echo $attachments_size[$i] ?>">
     <input type="hidden" name="attachments_file[]" value="<?php echo $attachments_file[$i] ?>">
     <input type="hidden" name="attachments_type[]" value="<?php echo $attachments_type[$i] ?>">
     <tr>
       <td align="center" bgcolor="#ddddaa"><?php $default->text_on_light->start(); ?>
         <input type="checkbox" name="delattachments[]" value="<?php echo $attachments_file[$i] ?>">
       </td>
       <td align="left" bgcolor="#ddddaa"><?php $default->text_on_light->start(); ?><?php echo $attachments_name[$i] ?></td>
       <td align="left" bgcolor="#ddddaa"><?php $default->text_on_light->start(); ?><?php echo $attachments_size[$i] ?></td>
     </tr>
  <?php } ?>
  <tr><td>&nbsp;</td><td align="right"><?php echo $lang->total_size ?></td><td><?php echo $total_size ?></td></tr>

  </table>
  </div>
  </td>
</tr>

<?php endif; ?>
*/
?>

<textarea tabindex="5" name="message" rows="21" cols="80" wrap="hard"><?php echo $msg ?></textarea>

<?php
/*
NO Spell check right now! 

<?php
if (isset($default->path_to_ispell)): ?>
  
  <td><input type="button" value="<?php echo $lang->button_cancel ?>" onClick="self.close();"></td>
  <td align="left">

<a href="javascript:spellcheck()"><?php echo $lang->button_spellcheck;
if (isset($default->ispell_lang)): echo $lang->spell_in; ?>
</a>
	 <select name="spell_lang" >
	 <?php
	 	reset($default->ispell_lang);
while (list($key,$val) = each($default->ispell_lang)) {
   echo "<option value=\"$key\">".$lang->lang[$key]."</option>\n";
}
</select>
<?php else: ?>
	</a>
<?php endif; ?>
 </td>
<?php endif; ?>
*/
?>

<center>
<input notab type="submit" name="actionID" value="<?php echo '[ ' . $lang->button_send . ' ]'; ?>">
</center>

<?php
/* NO ISPELL
<?php if (isset($default->path_to_ispell)): ?>
<form action="<?php echo $default->root_url ?>/spelling.php3" method="post" name="spelling" target="impspelling">
  <input type=hidden name="message" value="">
  <input type=hidden name="spell_lang" value="">
</form>
<?php endif; ?>
*/
?>
