<?php
/*
add_user.inc
$version$
$author$
*/
$title                  = 'Add Horde User';
$subtitle               =
'This form allows you to add a new horde user to the
 database, which enables them to get into the various horde modules.';
$action_url             = 'manager.php3';
$action_tag             = MGR_USER_ADD;
$horde_user_name        = '';
$horde_user_password    = '';
$horde_login_deny       = false;
echo( '<center>' );
echo( '<table bgcolor="' . $default->nav_bg . '" border="0" cellspacing="0">' );
require( "$default->include_dir/manager/user_attributes.inc" );
echo( '</table>' );
echo( '</center>' );
?>
