<html>
<head>
<?php if (isset($title)) echo "<title>$title</title>"; ?>

<script language="JavaScript">
<!-- Reload the folder select so the folder list is accurate
if (parent.impfolder) {
   parent.impfolder.location="select.php3";
}
//-->
</script>

</head>

<?php $default->body->generate_body(); ?>
