<table border="0" cellpadding="1" cellspacing="1" align="center" width="95%">
<tr bgcolor="<?php echo $default->nav_bg ?>">

    <form method="post" name="messages" action="<?php echo($del_target) ?>">

    <td align="left">
    <font face="<?php echo $default->font->face; ?>" size="4">
    <?php echo $lang->message_status($current_mbox, $msg_index, $num_msgs) ?>
    </font>
    </td>
    
    <td align="right">
    <font face="<?php echo $default->font->face; ?>" size="2">

    <a href="javascript:Transfer(<?php echo MOVE_MESSAGES ?>, 1)"><?php echo $lang->move_link ?></a>
    <a href="javascript:Transfer(<?php echo COPY_MESSAGES ?>, 1)"><?php echo $lang->copy_link ?></a>

    <select name="target1">
    <?php echo $options ?>
    </select>

    <input type="hidden" name="<?php echo $del_ident ?>" value="<?php echo $index ?>">
    <input type="hidden" name="start" value="<?php echo $array_index ?>">
    <input type="hidden" name="mailbox" value="<?php echo $mailbox ?>">
    <input type="hidden" name="targetMbox" value="">
    <input type="hidden" name="array_index" value="<?php echo $array_index ?>">
    <input type="hidden" name="actionID" value="">
    
    </font>
    </td>

    </form>
  
</tr>
</table>
