<script language="Javascript">
<!-- hide from stupid browsers
function open_compose_win (args) {
   var url = "compose.php3";
   if (args != "") url = url + "?" + args;
   param = "toolbar=no,location=no,status=yes,scrollbars=yes,resizable=yes,width=" + <?php echo $lang->compose_width ?> + ",height=" + <?php echo $lang->compose_height ?>;
   compose_window=window.open(url, "imp_compose", param);
   if (!compose_window.opener) compose_window.opener=self;
}
// -->
</script>
