<table border="0" align="center" width="95%" cellpadding="3" cellspacing="2">

<?php if (isset($dat)): ?>
<tr><td align="right" valign="top"><b><?php echo $lang->date ?></b></td><td width="100%" bgcolor="<?php echo $default->item_bg ?>" width="100%"><?php echo $dat ?></td></tr>
<?php endif; ?>

<?php if (isset($to)): ?>
<tr>
  <td align="right" valign="top"><b><?php echo $lang->to ?></b></td>
  <td width="100%" bgcolor="<?php echo $default->item_bg ?>">
    <a href="javascript:open_compose_win('actionID=<?php echo MAILTO ?>&mailbox=<?php echo urlencode($mailbox) ?>&index=<?php echo $index ?>&bodypart=<?php echo $bodypart ?>&to=<?php echo urlencode($to) ?>');"
      onMouseOver="status='<?php echo $lang->compose ?>'; return true;"
      onMouseOut="status='';">
      <?php echo $to ?></a>
  </td>
</tr>
<?php endif; ?>

<?php if (isset($frm)): ?>
<tr>
  <td align="right" valign="top"><b><?php echo $lang->from ?></b></td>
  <td width="100%" bgcolor="<?php echo $default->item_bg ?>">
    <a href="javascript:open_compose_win('actionID=<?php echo MAILTO ?>&mailbox=<?php echo urlencode($mailbox) ?>&index=<?php echo $index ?>&bodypart=<?php echo $bodypart ?>&to=<?php echo urlencode($frm) ?>');"
      onMouseOver="status='<?php echo $lang->compose ?>'; return true;"
      onMouseOut="status='';">
      <?php echo $frm ?></a>
  </td>
</tr>
<?php endif; ?>

<?php if (isset($cc)): ?>
<tr>
  <td align="right" valign="top"><b><?php echo $lang->cc ?></b></td>
  <td width="100%" bgcolor="<?php echo $default->item_bg ?>">
    <a href="javascript:open_compose_win('actionID=<?php echo MAILTO ?>&mailbox=<?php echo urlencode($mailbox) ?>&index=<?php echo $index ?>&bodypart=<?php echo $bodypart ?>&to=<?php echo urlencode($cc) ?>');"
      onMouseOver="status='<?php echo $lang->compose ?>'; return true;"
      onMouseOut="status='';">
    <?php echo $cc ?></a>
  </td>
</tr>
<?php endif; ?>

<?php if (isset($bcc)): ?>
<tr>
  <td align="right" valign="top"><b><?php echo $lang->bcc ?></b></td>
  <td width="100%" bgcolor="<?php echo $default->item_bg ?>">
    <a href="javascript:open_compose_win('actionID=<?php echo MAILTO ?>&mailbox=<?php echo urlencode($mailbox) ?>&index=<?php echo $index ?>&bodypart=<?php echo $bodypart ?>&to=<?php echo urlencode($bcc) ?>');"
      onMouseOver="status='<?php echo $lang->compose ?>'; return true;"
      onMouseOut="status='';">
      <?php echo $bcc ?></a>
  </td>
</tr>
<?php endif; ?>

<?php if (isset($rep) && (isset($rep)) && ($rep != $frm)): ?>
<tr>
  <td align="right" valign="top"><b><?php echo $lang->replyto ?></b></td>
  <td width="100%" bgcolor="<?php echo $default->item_bg ?>">
    <a href="javascript:open_compose_win('actionID=<?php echo MAILTO ?>&mailbox=<?php echo urlencode($mailbox) ?>&index=<?php echo $index ?>&bodypart=<?php echo $bodypart ?>&to=<?php echo urlencode($rep) ?>');"
      onMouseOver="status='<?php echo $lang->replyto ?>'; return true;"
      onMouseOut="status='';">
      <?php echo $rep ?></a>
  </td>
</tr>
<?php endif; ?>

<?php if (isset($sub)): ?>
<tr><td align="right" valign="top"><b><?php echo $lang->subject ?></b></td><td width="100%" bgcolor="<?php echo $default->item_bg ?>"><?php echo $sub ?></td></tr>
<?php endif; ?>

<?php if (isset($atc)): ?>
<tr><td align="right" valign="top"><b><?php echo $lang->parts ?></b></td><td width="100%" bgcolor="<?php echo $default->item_bg ?>"><?php echo $atc ?></td></tr>
<?php endif; ?>

</table>
