<?php
/*
The Actual calls to element includes and such are contained within
functions to prevent varaible collision in the main namespace.
*/
Function print_form() {
global $default;


$value      = $default->newmail_popup;
$desc_text  = 'New mail popup';
$name       = 'newmail_popup';
$desc       = 'Turns on/off the refresh of the new mail popup.';
include( './templates/setup/form_true_false_elem.inc' ); 

$value      = $default->refresh_delay;
$desc_text  = 'Refresh Delay';
$name       = 'refresh_delay';
$desc       = 'The time in seconds in between checks for new mail. Upon new mail arrival it tells you.';
$size       = 50;
include( './templates/setup/form_text_elem.inc' ); 

}

$form_subtitle = 'New Mail Notification Configuration';
include( './templates/setup/stub_form.inc' );

?>
