# mysql_create_users.sql
#
# This script creates the basic users for the horde / imp systems.
#
# you can simply direct this file to mysql as STDIN:
# mysql (user/pass/host args) < mysql_create.sql
# 
# done!
