/* Defines for types of imap servers.  */
/* MS_EXCHANGE_IMAP : Ms Exchange imap service. */
define( "MS_EXCHANGE_IMAP", 		1001 );
/* CYRUS_IMAP       : The cyrus imap server. */
define( "CYRUS_IMAP", 				2001 );
/* UNKNOWN_IMAP     : Otherwise known as RFC 822. */
define( "UKNOWN_IMAP",				9999 );
