<?php
/*
The Actual calls to element includes and such are contained within
functions to prevent varaible collision in the main namespace.
*/
Function print_form() {
global $default;
/*
THIS ISN"T IN 2.0
$value      = $default->session_enabled;
$desc_text  = 'Session enabled';
$name       = 'session_enabled';
$desc       = '';
include( './templates/setup/form_true_false_elem.inc' ); 

$value      = $default->session_timeout;
$desc_text  = 'Session timeout';
$size       = 50;
$name       = 'session_timeout';
$desc       = '';
include( './templates/setup/form_text_elem.inc' ); 

*/
$value      = $default->cookie_timeout;
$desc_text  = 'Cookie Timeout';
$size       = 50;
$name       = 'cookie_timeout';
$desc       = 'Time in seconds before the cookie times out and is no longer valid.';
include( './templates/setup/form_text_elem.inc' ); 

}

$form_subtitle = 'Cookie Configuration';
include( './templates/setup/stub_form.inc' );

?>
