<table border="0" align="center" width="95%" cellpadding="3" cellspacing="2">
    <tr>
        <td colspan="7" bgcolor="<?php echo $default->dark_bg ?>" align="center">
            <table border="0" width="100%" cellpadding="0" cellspacing="0">
               <tr>
                   <td align="left" width="33%"><?php $default->text_on_dark->start(); ?>
                      <b><?php echo $current_mbox ?></b></font>
		   </td>
                   <td align=right width="33%">
			  <?php $default->text_on_dark->start(); ?>
			  <b><?php echo $lang->overview($begin, $end, $nummsgs) ?></b></font>
		   </td>
               </tr>
	     </table>
	 </td>
     </tr>
