<table border="0" align="center" width="95%" cellpadding="3" cellspacing="2">
<tr bgcolor="<?php echo $default->dark_bg; ?>">
  <td colspan="3"><?php $default->text_on_dark->start(); ?><b><?php echo $ACTION_TEXT ?></b></font></td>
</tr>
<form method="post" 
      name="compose" 
      enctype="multipart/form-data"
      onSubmit="return submit_and_sign(this)">

<input notab type="hidden" name="mailbox" value="<?php echo $mailbox ?>">
<input notab type="hidden" name="index" value="<?php echo $index ?>">
<input notab type="hidden" name="actionID" value="<?php echo BOUNCE_MESSAGE ?>">

<tr>
  <td align="right" bgcolor="<?php echo $default->light_bg; ?>"><?php $default->text_on_light->start(); ?><?php echo $lang->to_string ?></td>
  <td colspan=2 bgcolor="<?php echo $default->item_bg ?>"><input type="text" size="70" tabindex="1" name="to" onBlur="expand_to()" value="<?php echo $to ?>"></td>
</tr>

<tr>
  <td>&nbsp;</td>
  <td colspan=2 align=center>
    <input notab type="submit" value="<?php echo $lang->button_bounce ?>">
  </td>
</tr>

</form>

</td></tr></table>
