<tr>
  <th bgcolor="<?php echo $default->item_bg ?>" align=center><a href="mailbox.php3?mailbox=<?php echo urlencode($mailbox) ?>&sortby=<?php echo $sortby ?>&sort_reverse=<?php echo abs(1 - $sort_reverse); ?>"><img src="<?php echo "$default->graphics_url/" . ($sort_reverse ? "lg-sm.gif" : "sm-lg.gif"); ?>" border="0" alt="<?php echo $lang->reverse_sort ?>"></a></th>
  <th bgcolor="<?php echo $default->item_bg ?>" align=center>?</th>
  <th bgcolor="<?php echo ($sortby == SORTDATE) ? $default->sort_bg : $default->item_bg ?>" align=left>
    <a href="mailbox.php3?mailbox=<?php echo urlencode($mailbox) ?>&sortby=<?php echo SORTDATE ?>&sort_reverse=<?php echo $sort_reverse ?>"><font face="<?php echo $default->font->face; ?>"><?php echo $lang->date_label ?></font></a>
  </th>
  <th bgcolor="<?php echo ($sortby == SORTFROM) ? $default->sort_bg : $default->item_bg ?>" align=left>
    <a href="mailbox.php3?mailbox=<?php echo urlencode($mailbox) ?>&status=green&sortby=<?php echo SORTFROM ?>&sort_reverse=<?php echo $sort_reverse ?>"><font face="<?php echo $default->font->face; ?>"><?php echo $lang->from_label ?></font></a>
  </th>
  <th bgcolor="<?php echo ($sortby == SORTSUBJECT) ? $default->sort_bg : $default->item_bg ?>" align=left>
    <a href="mailbox.php3?mailbox=<?php echo urlencode($mailbox) ?>&status=green&sortby=<?php echo SORTSUBJECT ?>&sort_reverse=<?php echo $sort_reverse ?>"><font face="<?php echo $default->font->face; ?>"><?php echo $lang->subject_label ?></font></a>
  </th>
  <th bgcolor="<?php echo ($sortby == SORTSIZE) ? $default->sort_bg : $default->item_bg ?>" width=10 align="right">
    <a href="mailbox.php3?mailbox=<?php echo urlencode($mailbox) ?>&status=green&sortby=<?php echo SORTSIZE ?>&sort_reverse=<?php echo $sort_reverse ?>"><font face="<?php echo $default->font->face; ?>"><?php echo $lang->size_label ?></font></a>
  </th>
  <th bgcolor="<?php echo $default->item_bg ?>" width=10><font face="<?php echo $default->font->face; ?>">&nbsp;</font></th>
</tr>
