<html>
<head>
<?php if (isset($title)) echo "<title>$title</title>"; ?>
<?php if (isset($refresh) && $refresh) echo "<meta http-equiv=\"refresh\" content=\"", $default->refresh_delay, "\">"; ?>
<?php if (isset($charset)) echo "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=$charset\">"; ?>
</head>

<?php
   if (isset($sidebar)&&$sidebar) { $default->sidebar->generate_body(); } 
   else { $default->body->generate_body(); }
?>
