<table border="0" align="center" width="95%" cellpadding="0" cellspacing="0">
<form method="post" name="addressbook">
<tr>
  <td bgcolor="<?php echo $default->dark_bg ?>" align="left">
    <?php $default->text_on_dark->start(); ?><b><?php echo $lang->contacts ?></b></font>
  </td>
  <td bgcolor="<?php echo $default->dark_bg ?>" align="right">

  <a href="javascript:parent.close()"><?php $default->text_on_dark->start(); ?><b><?php echo $lang->close_window ?></b></font></a>

</td>
</tr>
<tr>
  <td align="right"><font size=-1><INPUT type="button" Value="<?php echo $lang->select ?>" onClick="setFields_ins()">&nbsp;</font></td>
  <td align="left" bgcolor="<?php echo $default->item_bg ?>">
    <select name="old_address" onchange="setFields_ins()"><?php echo "\n" . $options ?>
    </select>
  </td>
</tr>
<tr>
  <td align="right"><?php echo $lang->address_string ?>&nbsp;</td>
  <td align="left" bgcolor="<?php echo $default->item_bg ?>"><input type="text" name="new_address" onBlur="expand_new_address()" value="<?php echo $new_address ?>" size="40"></td>
</tr>
<tr>
  <td align="right"><?php echo $lang->nickname_string ?>&nbsp;</td>
  <td align="left" bgcolor="<?php echo $default->item_bg ?>"><input type="text" name="new_nickname" value="" size="40"></td>
</tr>
<tr>
  <td align="right"><?php echo $lang->fullname_string ?>&nbsp;</td>
  <td align="left" bgcolor="<?php echo $default->item_bg ?>"><input type="text" name="new_fullname" value="" size="40"></td>
</tr>
<tr>
<td colspan="2" align=center>
<font size=-1>
<input type="button" value="<?php echo $lang->ldap_clear ?>" onClick="ClearSelection();">
<select name="actionID">
<option value="<?php echo ADD_ADDR ?>"> <?php echo $lang->add_contact ?>
<option value="<?php echo DELETE_ADDR ?>"> <?php echo $lang->del_contact ?>
<option value="<?php echo UPDATE_ADDR ?>"> <?php echo $lang->update_contact ?>
</select>
<input type="submit" value="Submit">
<br><input type="button" value="<?php echo $lang->insert_into_to ?>" onClick="insert_addr();">&nbsp;<input type="button" value="<?php echo $lang->insert_into_cc ?>" onClick="insert_addr_cc();">&nbsp;<input type="button" value="<?php echo $lang->insert_into_bcc ?>" onClick="insert_addr_bcc();">
</font>
</td>
</tr>
</form>
</table>
