<?php
/*
edit_user_select.inc
$version$
$author$
*/

$title               = 'Select a user to edit';
$action_text         = 'Edit';
$action_url          = 'manager.php3';
$action_id           = MGR_USER_EDIT_FRM;
require( "$default->include_dir/manager/user_navigator.inc" );

?>
