/* This file is (c) 1998 Juraj Bednar. Any comments to <bednar@isternet.sk> */
/* STATE : This file _MAY_ work, it has been completely untested... */

/* Table Structure for Informix version:
   
   Preferences Table:
    field:     type:      description:
    user       text       joe@imap.doe.com format username
    sig        text       signature
    replyto    text       joe@doe.com address
    fullname   text       Joe Doe
    (possibly more to be added later)
 
   Address Table:
    field:     type:      description:
    user       text       joe@doe.com identifier of who this entry belongs to
    address    text       address@mail.server.com - the actual address
    nickname   text       any entered nickname - ie "bonnie".
    fullname   text       full name - "My Bonnie".
*/
