<?php

$need_horde_db = 0;
$db_lib_loaded = 0;
if (!defined("HORDE_LIB")) include ('../lib/horde.lib');
require( './lib/imp.lib' );
require( './config/defaults.php3' );
$language = select_lang();
require ("./locale/$language/contacts.lang");
require ('./locale/local/contacts.lang');


$title            = '';
$sidebar          = false;
require( "$default->include_dir/generic-header.inc" );

?>
<body bgcolor="#e9e9e9">
<center>
<font size="+1"><?php echo $lang->before_search; ?></font>
</center>

<?php require( "$default->include_dir/generic-header.inc" ); ?>
