<?php
/*
edit_user.inc
$version$
$author$
*/
$title                  = 'Edit Horde User';
$subtitle               =
'This form allows you to edit a horde user';
$action_url             = 'manager.php3';
$action_tag             = MGR_USER_EDIT;
$horde_user_name        = '';
$horde_user_password    = '';
$horde_login_deny       = false;
$ReturnArray = $db->User->ListAll();
$status = $ReturnArray[ 0 ];

if ( $status == true ) {
   list( $status, $ResultCount, $ResultArray ) = $ReturnArray;
   } else {
   list( $status, $error_id, $reason ) = $ReturnArray;
   echo( $reason );
   }


$temp_obj = $ResultArray[ $selected_user_id ];
$horde_user_name           = $temp_obj->user_name;
$horde_user_password       = $temp_obj->password;
$horde_user_id             = $temp_obj->user_id;
$horde_login_deny          = $temp_obj->login_deny;


echo( '<center>' );
echo( '<table bgcolor="' . $default->nav_bg . '" border="0" cellspacing="0">' );
require( "$default->include_dir/manager/user_attributes.inc" );
echo( '</table>' );
echo( '</center>' );
?>
