<script language="JavaScript">
<!--

function open_contacts_ldap_win() {
   parem="directories=no,menubar=no,toolbar=no,resizable=yes,width=" + <?php echo $lang->contact_ldap_width ?> + ",height=" + <?php echo $lang->contact_ldap_height ?>;
   contacts_window=window.open("contacts.html", "contacts", parem);
   if (!contacts_window.opener) contacts_window.opener=self;
}

function open_contacts_ldap_noaddy_win() {
   parem="directories=no,menubar=no,toolbar=no,resizable=yes,width=" + <?php echo $lang->contact_ldap_noaddy_width ?> + ",height=" + <?php echo $lang->contact_ldap_noaddy_height ?>;
   contacts_window=window.open("contacts_ldap.html", "contacts", parem);
   if (!contacts_window.opener) contacts_window.opener=self;
}

function open_contacts_win() {
   parem="directories=no,menubar=no,toolbar=no,resizable=yes,width=" + <?php echo $lang->contact_width ?> + ",height=" + <?php echo $lang->contact_height ?>;
   contacts_window=window.open("contacts.php3", "contacts", parem);
   if (!contacts_window.opener) contacts_window.opener=self;
}

function open_add_contact_win (args) {
   var url = "addcontact.php3";
   if (args != "") url = url + "?" + args;
   parem="directories=no,menubar=no,toolbar=no,resizable=yes,width=" + <?php echo $lang->contact_add_width ?> + ",height=" + <?php echo $lang->contact_add_height ?>;
   add_contact_window=window.open(url, "add_contact", parem);
   if (!contacts_window.opener) contacts_window.opener=self;
}


//-->
</script>

