<table border="0" align="center" width="95%">
<tr bgcolor="<?php echo $default->nav_bg ?>">
<td align=left>
<font size=2 face="<?php echo $default->font->face; ?>">

<a href="<?php echo $del_target ?>?actionID=<?php echo DELETE_MESSAGES ?>&<?php echo $del_ident ?>=<?php echo $index ?>&mailbox=<?php echo urlencode($mailbox) ?>&start=<?php echo $array_index ?>&array_index=<?php echo $array_index ?>"><?php echo $lang->delete ?></a> - 
<a href="javascript:open_compose_win('actionID=<?php echo REPLY ?>&mailbox=<?php echo urlencode($mailbox) ?>&index=<?php echo $index ?>&bodypart=<?php echo $bodypart ?>');"><?php echo $lang->reply ?></a> -
<a href="javascript:open_compose_win('actionID=<?php echo REPLY_ALL ?>&mailbox=<?php echo urlencode($mailbox) ?>&index=<?php echo $index ?>&bodypart=<?php echo $bodypart ?>');"><?php echo $lang->replyall ?></a> -
<a href="javascript:open_compose_win('actionID=<?php echo FORWARD ?>&mailbox=<?php echo urlencode($mailbox) ?>&index=<?php echo $index ?>&bodypart=<?php echo $bodypart ?>');"><?php echo $lang->forward ?></a> -
<a href="javascript:open_compose_win('actionID=<?php echo BOUNCE_COMPOSE ?>&mailbox=<?php echo urlencode($mailbox) ?>&index=<?php echo $index ?>');"><?php echo $lang->bounce ?></a> -

<a href="<?php echo $default->root_url ?>/view.php3?actionID=<?php echo SAVE_MESSAGE ?>&index=<?php echo $index ?>&mailbox=<?php echo urlencode($mailbox) ?>"><?php echo $lang->saveas ?></a> <?php if (($default->user_use_addressbook == true) && $default->use_db): ?>
-
<a href="javascript:open_add_contact_win('actionID=<?php echo ADD_CONTACT ?>&mailbox=<?php echo urlencode($mailbox) ?>&index=<?php echo $index ?>&bodypart=<?php echo $bodypart ?>');"><?php echo $lang->add_to_contacts ?></a>
<?php endif; ?>


</font>
</td>
<td align=right>
<font size=2 face="<?php echo $default->font->face; ?>">
  
<a href="mailbox.php3?mailbox=<?php echo urlencode($mailbox) ?>&start=<?php echo $array_index+1 ?>"><?php echo $lang->back_to($current_mbox) ?></a>&nbsp;&nbsp;

<?php if ($array_index != 0): ?>
  <a href="message.php3?mailbox=<?php echo urlencode($mailbox) ?>&index=<?php echo $prev ?>&array_index=<?php echo $prev_index ?>">
  <img src="<?php echo( $default->graphics_url ); ?>/prev.gif" width="12" height="12" alt="<?php echo $lang->prev ?>" border="0"></a>
  
<?php else: ?>
  <img src="<?php echo( $default->graphics_url ); ?>/prev-grey.gif" width="12" height="12" alt="" border="0">
  
<?php endif; ?>


<?php if (($array_index + 1) != count($sorted)): ?>
  <a href="message.php3?mailbox=<?php echo urlencode($mailbox) ?>&index=<?php echo $next ?>&array_index=<?php echo $next_index ?>">
  <img src="<?php echo( $default->graphics_url ); ?>/next.gif" width="12" height="12" alt="<?php echo $lang->next ?>" border="0"></a>
  
<?php else: ?>
  <img src="<?php echo( $default->graphics_url ); ?>/next-grey.gif" width="12" height="12" alt="" border="0">
  
<?php endif; ?>

</font>
</td></tr></table>
