# mysql_create_all.sql 
# All the ver1 mysql scripts rolled into one
# you can simply direct this file to mysql as STDIN:
# mysql (user/pass/host args) < mysql_create.sql
# 

\r mysql

INSERT INTO user ( host, user, password )
   VALUES (
      'localhost',
      'impmgr',
      password( 'impmgr' )
      );

INSERT INTO db (
      host, db, user,
         Select_priv, Insert_priv, Update_priv, Delete_priv,
         Create_priv, Drop_priv )
      VALUES (
      'localhost',
      'imp',
      'impmgr',
      'Y', 'Y', 'Y', 'Y',
      'Y', 'Y' 
        );

CREATE DATABASE imp;
\r imp

# create the address table
CREATE TABLE imp_addr (
  user text,
  address text,
  nickname text,
  fullname text
);


# now create the pref table
CREATE TABLE imp_pref (
  user text,
  fullname text,
  replyto text,
  lang varchar(30),
  sig text
);

# done!
