<tr bgcolor="<?php echo $default->nav_bg; ?>">
   <td><b><?php echo $desc_text; ?> :</b></td>
   <td>
   <select name="<?php echo $name; ?>">
   <option <?php if ( $value == true   || $value == 'true' ) { echo( 'selected' ); } ?> value="true">True</option>
   <option <?php if ( $value == false  || $value == 'false' ) { echo( 'selected' ); } ?> value="false">False</option>
   </select>
</tr>
<?php include( './templates/setup/form_elem_desc.inc' ); ?>
