<?php
/*
user_attributes.inc
$version$
$author$

To use setup :
$title
$subtitle
$action_url
$action_tag
$horde_user_name
*/


echo( '<form action="' . $action_url . '" method="post">' );
if ( $horde_config_frm == undef || $horde_config_frm == '') { 
$horde_config_frm = new HordeConfigForm;
}
$horde_config_frm->full_colspan = 2;
$horde_config_frm->gen_action_tag( $action_tag );
$horde_config_frm->gen_title_bar( $title );
$horde_config_frm->gen_sect_subtitle( $subtitle );
$horde_config_frm->gen_attr_value_title();
if ( $horde_user_id != '' ) {
echo( '<input type="hidden" name="horde_user_id" value="' . $horde_user_id . '">' );
}

$horde_config_frm->gen_text_option(
      'User Name :',          /* English Text */
      'horde_user_name',      /* form item_name */
      30,                     /* Size */
      $horde_user_name,       /* Default Value */
      'The user name that identifies that user.' /* Text comment */
   );
$horde_config_frm->gen_text_option(
      'Password :',
      'horde_user_password',
      30,
      $horde_user_password,
      'The pasword for the user.'
   );
$horde_config_frm->gen_true_false(
      'Login Deny :',
      'horde_login_deny',
      $horde_login_deny,
      'A true value, allows a user to NOT login.'
      );

$horde_config_frm->gen_submit_reset();
echo( '</form>' );

?>

