<?php
/*
The Actual calls to element includes and such are contained within
functions to prevent varaible collision in the main namespace.
*/
Function print_form() {
global $default;

$desc_text  = 'Use Database';
$size       = 30;
$name       = 'use_db';
$value      = $default->use_db;
include( './templates/setup/form_true_false_elem.inc' );

$value            = $default->database_driver;
$possible         = Array();
$possible_vals    = Array();
$possible[]       = 'NONE';
$possible_vals[]  = 'dummy_driver';
$possible[]       = 'Mysql';
$possible_vals[]  = 'mysql';
$possible[]       = 'Oracle';
$possible_vals[]  = 'oracle';
$possible[]       = 'Postgres';
$possible_vals[]  = 'postgres';
$possible[]       = 'Informix';
$possible_vals[]  = 'informix';
$desc_text  = 'Database Type';
$size       = 50;
$name       = 'database_driver';
$desc       = '';
include( './templates/setup/form_multiselect_elem.inc' );

$desc_text  = 'User Name';
$size       = 30;
$name       = 'db_user_name';
$value      = $default->db_user_name;
$desc       = '';
include( './templates/setup/form_text_elem.inc' );

$desc_text  = 'Password';
$size       = 30;
$name       = 'db_password';
$value      = $default->db_password;
$desc       = '';
include( './templates/setup/form_text_elem.inc' );

$desc_text  = 'Database Name';
$size       = 30;
$name       = 'db_name';
$value      = $default->db_name;
$desc       = '';
include( './templates/setup/form_text_elem.inc' );

$desc_text  = 'Server Name';
$size       = 30;
$name       = 'db_server_name';
$value      = $default->db_server_name;
$desc       = '';
include( './templates/setup/form_text_elem.inc' );

$desc_text  = 'Preferences Table';
$size       = 30;
$name       = 'db_pref_table';
$value      = $default->db_pref_table;
$desc       = '';
include( './templates/setup/form_text_elem.inc' );

$desc_text  = 'Address Table';
$size       = 30;
$name       = 'db_address_table';
$value      = $default->db_address_table;
$desc       = '';
include( './templates/setup/form_text_elem.inc' );

/*

--- Some other fields ommited ... ( ithink they are not used....
$default->db_connect_string         = '';
$default->db_server_port            = '';
$default->db_server_options         = '';
$default->db_server_tty             = '';
*/
}

$form_subtitle = 'Database Configuration';
include( './templates/setup/stub_form.inc' );


?>
