/* Table Structure for PostgreSQL version:
   
   Preferences Table (possibly more to be added later):

    create table imp_pref (
      username   text,        -- joe@imap.doe.com format username
      sig        text,        -- signature
      replyto    text,        -- joe@doe.com for replyto/from lines
      fullname   text,        -- Joe Doe
      lang       varchar(30)  -- users's preferred language (en, es, ...)
    );

   Address Table:

   create table imp_addr (
     username   text,     -- joe@doe.com identifier of who this entry belongs to
     address    text,     -- address@mail.server.com - the actual address
     nickname   text,     -- any entered nickname - ie "bonnie".
     fullname   text      -- full name - "My Bonnie".
   );

*/
