<table border="0" align="center" width="95%" cellpadding="3" cellspacing="0">
<form method="post" name="create">
<input type="hidden" name="actionID" value="<?php echo CREATE_FOLDER ?>">

<tr bgcolor="<?php echo $default->dark_bg ?>">
  <td colspan="2" align="left">
    <?php $default->text_on_dark->start(); ?><b><?php echo $lang->create_label ?></b></font>
  </td>
  <td align="right"><?php $help->link(FOLDERS_HELP_CREATE, $help_file, 'imp') ?></td>
</tr>
<tr>
  <td align="right"><?php echo $lang->create ?></td>
  <td colspan="2" align="left" bgcolor="<?php echo $default->item_bg ?>"><input type="text" size="60" name="new_mailbox"></td>
</tr>
<tr><td colspan="3" align="center"><input type="submit" value="<?php echo $lang->create_button ?>"></td></tr>

</form>
</table>
