/* Table Structure for MySQL version:
 
 Preferences Table:
 field:     type:        description:
 user       text         joe@imap.doe.com format username
 sig        text         signature
 fullname   text         'Joe Doe' 
 replyto    text         joe@doe.com format
 lang       varchar(30)  users's preferred language (en, es, ...)
 (possibly more to be added later)
 
 Address Table:
 field:     type:      description:
 user       text       joe@doe.com identifier of who this entry belongs to
 address    text       address@mail.server.com - the actual address
 nickname   text       any entered nickname - ie "bonnie".
 fullname   text       full name - "My Bonnie".
 */
