<table border="0" align="center" width="95%" cellpadding="1" cellspacing="0">
<form method="post" name="addressbook">
<tr>
  <td bgcolor="<?php echo $default->dark_bg ?>" align="left">
    <?php $default->text_on_dark->start(); ?><b><?php echo
        $lang->add_to_contacts ?></b></font>
  </td>
  <td bgcolor="<?php echo $default->dark_bg ?>" align="right">

  <a href="javascript:parent.close()"><?php $default->text_on_dark->start(); ?><b><?php echo $lang->close_window ?></b></font></a>

</td>
</tr>
<tr>
  <td align="right"><?php echo $lang->address_string ?>&nbsp;</td>
  <td align="left" bgcolor="<?php echo $default->item_bg ?>"><input type="text" name="new_address" onBlur="expand_new_address()" value="<?php echo $new_address ?>" size="40"></td>
</tr>
<tr>
  <td align="right"><?php echo $lang->nickname_string ?>&nbsp;</td>
  <td align="left" bgcolor="<?php echo $default->item_bg ?>"><input type="text" name="new_nickname" onBlur="expand_new_nickname()" value="<?php echo $new_nickname ?>" size="40"></td>
</tr>
<tr>
  <td align="right"><?php echo $lang->fullname_string ?>&nbsp;</td>
  <td align="left" bgcolor="<?php echo $default->item_bg ?>"><input type="text" name="new_fullname" onBlur="expand_new_fullname()" value="<?php echo $new_fullname ?>" size="40"></td>
</tr>
<tr>
<td colspan="2" align=center>
<font size=-1>
<input type="button" value="<?php echo $lang->ldap_clear ?>" onClick="ClearSelection();">
<input type="hidden" name="actionID" value="<?php echo ADD_ADDR ?>">
<input type="submit" value="Submit">
</font>
</td>
</tr>
</form>
</table>
