<?php

/*
 
 File: select.php3
 $Author: chuck $
 $Revision: 1.31 $
 $Date: 1999/04/11 01:56:31 $
 
 IMP: Copyright 1999 Charles J. Hagenbuch  <chuck@horde.org>
 
 You should have received a copy of the GNU Public
 License along with this package; if not, write to the
 Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.
 
 */

$need_horde_db = 0;
$db_lib_loaded = 0;
if (!defined("HORDE_LIB")) include ('../lib/horde.lib');
require( './lib/imp.lib' );             /* IMPlib is the IMP function library  */
require( './config/defaults.php3' );    /* Defaults configuration file */

/* Html styles configuration */
require('./config/html.php3');
/* Mailbox configuration */
require('./config/mailbox.php3');
/* include mime and language configuration */
require('./config/mime.php3');
require('./config/lang.php3');

$language = select_lang();
require ("./locale/$language/select.lang");
require ('./locale/local/select.lang');

error_reporting($default->error_level); /* set error level from imp.lib   */

/* send headers to ensure that the page will reload correctly. */
caching_headers();

$session = create_session_object();
$user    = $session->get_user();
$pass    = $session->get_password();
$server  = $session->get_server();
$port    = $session->get_port();
$folders = $session->get_folder();

$sidebar = true;

$mbox = validate_login($server, $port, '', $user, $pass, OP_HALFOPEN);

require("$default->include_dir/doctype.inc");
require("$default->include_dir/select/header.inc");
$options = mailbox_list();

if (isset($mbox) && $mbox) {
   include("$default->include_dir/select/body.inc");
   include("$default->include_dir/generic-footer.inc");
}

?>
