#!/bin/sh

chmod 555 config/defaults.php3
chmod 555 ../lib/horde.lib
chmod 555 lib/db.lib
chmod 555 lib/imp.lib
chmod 555 ../lib/mime.lib
chmod 555 lib/mimetypes.lib

chmod 000 setup.php3

echo 
echo I have made your configuration files, and libraries mode 0555
echo which is read / execute for everyone.
echo
echo And the setup.php3 is mode 0000 which is no access period.
echo 
echo 
