<?php

/*
   This is the IMAP server config file. You do need this if you set
   $default->user_change_server to false and $default->use_server_list
   The IMAPServer class looks something like this:

   class IMAPServer {
   
      var $name;
      var $server;
      var $port;
      var $folders;
      var $preferred;
   
   (...)
   }
   
   name specifies the name to be displayed for the server in the
   select box, server is the hostname of the server. port is the imap port -
   by default 143. folders is the $folders variable to use; by default
   it's set to ''.
   
   preferred is only useful if you do want to use the same server.php3
   file for different machines: if the Hostname of the IMP Machine is
   identical to one of those in the preferred list, then the according
   option in the select box will include a SELECTED, ie. it is 
   selected per default. Otherwise the first entry in the list is 
   selected.
   
   The following is an example configuration:

*/

$IMAPServers = array();

$IMAPServers['mail1'] = new IMAPServer('Mail1 (Institutsangeh&ouml;rige)',
				       'mail1.uibk.ac.at',
				       143,
				       'mail/',
				       array("webmail1.uibk.ac.at", "mm1-c102.uibk.ac.at"));

$IMAPServers['mail2'] = new IMAPServer('Mail2 (Studierende)',
				       'mail2.uibk.ac.at',
				       143,
				       'mail/',
				       'webmail2.uibk.ac.at');

$IMAPServers['mail3'] = new IMAPServer('Illustration of Defaults',
				       'mail.default.com');

?>
