<html>
<head>
<title>IMP Setup Program - <?php echo( $form_title ); ?></title>
</head>
<body bgcolor="<?php echo $default->light_bg ; ?>" text="<?php echo $default->text_on_light->color; ?>">
<font face="<?php echo $default->font->face; ?>" color="<?php $default->text_on_light->color; ?>">
