<html>
<head>
<title>IMP Configurator</title>
</head>
<?php $default->body->generate_body() ?>

<noscript>
<p><b>IMP requires JavaScript to perform certain message handling functions</b></p>
</noscript>

<center>
<table border=0 cellspacing=0 cellpadding=0>
