<tr>
  <td bgcolor="<?php echo $default->text_bg ?>" colspan="2">&nbsp;</td>
  <td bgcolor="<?php echo $default->text_bg ?>" colspan="4">
  <table border="0" width="100%"><tr><td align="left">
    <font face="<?php $default->font->face; ?>" size="2">
    <a href="javascript:ToggleAll(true)"
      onMouseOver="status='<?php echo $lang->select_all ?>'; return true;">
      <?php echo $lang->select_all ?></a> - 
    <a href="javascript:ToggleAll(false)"
      onMouseOver="status='<?php echo $lang->select_none ?>'; return true;">
      <?php echo $lang->select_none ?></a>
    </font>
  </td>
  <td align="right">
    <font face="<?php $default->font->face; ?>" size="2">
    <a href="mailbox.php3?actionID=<?php echo EXPUNGE_MAILBOX ?>&mailbox=<?php echo urlencode($mailbox) ?>&page=<?php echo $page ?>"
      onMouseOver="status='<?php echo $lang->empty_trash ?>'; return true;">
      <?php echo $lang->empty_trash ?></a>
    </font>
  </td></tr></table>
</td><td bgcolor="<?php echo $default->text_bg ?>">&nbsp;</td></tr>
