<?php

/* set theme colors */
$default->dark_bg                   = '#002266';
$default->light_bg                  = '#e9e9e9';

$default->font->face                = 'Geneva,Arial,Helvetica';
$default->text_on_light->color      = '#000000';
$default->text_on_light->face       = $default->font->face;
$default->text_on_dark->color       = '#ffffff';
$default->text_on_dark->face        = $default->font->face;

$default->text_bg                   = '#ffffff';
$default->item_bg                   = '#ffffcc';
$default->new_item_bg               = '#eeeeff';
$default->del_item_bg               = '#cccccc';
$default->nav_bg                    = '#dcdcdc';
$default->sort_bg                   = '#ffdd88';

$default->body->bg_color            = $default->light_bg;
$default->body->bg_file             = '';
$default->body->text_color          = $default->text_on_light->color;
$default->body->link_color          = '#0000ff';
$default->body->vlink_color         = '#0000aa';
$default->body->alink_color         = '#0000ff';
$default->sidebar->bg_color         = $default->dark_bg;
$default->sidebar->text_color       = $default->text_on_dark->color;
$default->sidebar->link_color       = '#e0e0e0';
$default->sidebar->vlink_color      = '#dddddd';
$default->sidebar->alink_color      = '#ffffff';
$default->sidebar->logo           	= true;
$default->sidebar->logo_url       	= 'impsmall.gif';
$default->sidebar->local_site_logo	= false;
$default->sidebar->local_site_logo_url	= '';

?>
