<?php

/*
  
  File: manager.php3
  $Author: chuck $
  $Revision: 1.12 $
  $Date: 1999/04/11 01:56:30 $
  
  IMP: Copyright 1998 Charles J. Hagenbuch  <chuck@horde.org>
  
  You should have received a copy of the GNU Public
  License along with this package; if not, write to the
  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA 02111-1307, USA.
  
*/

if (!defined("HORDE_LIB")) include ('../lib/horde.lib');
require('./lib/imp.lib');      /* IMPlib is the IMP function library  */
require('./config/defaults.php3');

/* Html styles configuration */
require('./config/html.php3');
/* Mailbox configuration */
require('./config/mailbox.php3');
/* include mime and language configuration */
require('./config/mime.php3');
require('./config/lang.php3');

$language = select_lang();
error_reporting( $default->error_level );


switch ( $action ) {
   case MGR_USER_ADD_FRM:
      $mode             = $action;
      $sidebar          = false;
      break;
   case MGR_USER_EDIT_SELECT_FRM:
      $mode             = $action;
      $sidebar          = false;
      break;
   case MGR_USER_EDIT_FRM:
      $mode             = $action;
      $sidebar          = false;
      break;
   case MGR_USER_ADD:
      $mode             = $action;
      $sidebar          = false;
      break;
   case MGR_USER_EDIT:
      $mode             = $action;
      $sidebar          = false;
      break;
}

$title   = 'Horde Manager';
require( "$default->include_dir/doctype.inc" );
require( "$default->include_dir/generic-header.inc" );

Function create_action_item( $id, $text ) {
   echo( '<A Href="testdriver.php3?action=' .
      $id .
      '">' . $text . '</a>' );
}

switch ( $mode ) {

   case MGR_USER_ADD_FRM:
      include( "$default->include_dir/manager/add_user.inc" );
      break;

   case MGR_USER_EDIT_SELECT_FRM:
      include( "$default->include_dir/manager/edit_user_select.inc" );
      break;

   case MGR_USER_EDIT_FRM:
      include( "$default->include_dir/manager/edit_user.inc" );
      break;
   
   case MGR_USER_ADD:
      include( "$default->include_dir/manager/add_user_results.inc" );
      break;

   case MGR_USER_EDIT:
      include( "$default->include_dir/manager/edit_user_results.inc" );
      break;

   default:
}
?>



<!-- FOOTER --> 
<HR>
Horde Manager
<BR>
By: ZeroDiVide
</BODY>
</HTML>
