<tr>
  <td bgcolor="<?php echo $default->nav_bg ?>" colspan=2>&nbsp;</td>
  <td bgcolor="<?php echo $default->nav_bg ?>" colspan=5>
  <table border=0 width="100%">
      <tr>
          <td align=left>
             <font face="<?php echo $default->font->face; ?>" size=2>
                <a href="javascript:Submit(<?php echo DELETE_MESSAGES ?>)"
		  onMouseOver="status='<?php echo $lang->delete_link ?>'; return true;"
		  onMouseOut="status='';">
		  <?php echo $lang->delete_link ?></a>
                <a href="javascript:Submit(<?php echo UNDELETE_MESSAGES ?>)"
		  onMouseOver="status='<?php echo $lang->undelete_link ?>'; return true;"
		  onMouseOut="status='';">
		  <?php echo $lang->undelete_link ?></a>
                <?php echo $lang->selected_mail ?>
             </font>
          </td>
  
          <form method="post" name="pagenav1">
             <input type="hidden" name="mailbox" value="<?php echo $mailbox ?>">
  
             <td align=center>
                <font face="<?php echo $default->font->face; ?>" size=2>
                   <?php if (isset($page_count)): ?>
                        <?php echo $pages_first ?><?php echo $pages_prev ?><?php echo $lang->pagenav($page, $page_count) ?><?php echo $pages_next ?><?php echo $pages_last ?>
                   <?php endif; ?>
                 </font>
             </td>
  
          </form>
		     
          <form method="post" name="messages">
	      <td align=right>
                  <font face="<?php echo $default->font->face; ?>" size=2>
                     <a href="javascript:Transfer(<?php echo MOVE_MESSAGES ?>, 1)"
			onMouseOver="status='<?php echo $lang->move_link ?>'; return true;"
			onMouseOut="status='';">
			<?php echo $lang->move_link ?></a>
                     <a href="javascript:Transfer(<?php echo COPY_MESSAGES ?>, 1)"
			onMouseOver="status='<?php echo $lang->copy_link ?>'; return true;"
			onMouseOut="status='';">
			<?php echo $lang->copy_link ?></a>
                     <select name="target1">
                        <?php echo $options ?>
                     </select>
                  </font>
               </td>
       </tr>
   </table>
   </td>
</tr>





