<frameset rows="40,*" frameborder="no" border=0>
   
  <frameset cols="250,*" frameborder="no" border=0>
      <frame name="impfolder"
         src="menu.php3?menu=999"
         scrolling="no"
      >
      <frame name="impstatus"
         src="status.php3"
         scrolling="no"
      >
   </frameset>
    
  
    <frameset rows="100%" cols="120,*"name="imp">
      <frame name="impmenu"
	src="menu.php3"
	scrolling="no"
      >
      <frame name="impmain"
	src="login.php3"
      >
    </frameset>

  </frameset>

