<?php
$form_subtitle                = 'Confirm File Write - This is what your defaults.php3 will look like.';
include( './templates/setup/form_header.inc' );
?>

<center>
   <form method="post" action="setup.php3">
   <?php hidden_elems( $form_next ); ?>
   <table cellspacing="0" border="1"> 

   <tr bgcolor="<?php echo( $default->dark_bg ); ?>">
      <td align="left">
      <img src="<?php echo( $default->graphics_url  . '/impsmall.gif' ); ?>" alt="IMP">
      </td>
      <td align="right">
      <font color="<?php echo $default->text_on_dark->color; ?>">
      <h3><?php echo( $form_title ); ?></h3>
      </td>
   </tr>

   <tr bgcolor="<?php echo $default->item_bg; ?>">
      <td colspan="2">
      <h4><?php echo( $form_subtitle ); ?> :</h4>
      </td>
   </tr>

   <tr bgcolor="<?php echo $default->light_bg; ?>">
      <td colspan="2">
      <pre><?php echo( htmlspecialchars( create_defaults_php3() ) ); ?></pre>
      </td>
   </tr>

   <tr bgcolor="<?php echo $default->item_bg; ?>">
      <td colspan="2">
      <center>
      <b>
         <input type="submit"    name="go" value="&lt-- Back">
         <input type="submit"    name="go" value="Write File --&gt">
         </form>
      </b>
      </center>
      </td>
   </tr>
   </table>
</center>
<?php
include( './templates/setup/form_footer.inc' );
?>
