<?php
/*
The Actual calls to element includes and such are contained within
functions to prevent varaible collision in the main namespace.
*/
Function print_form() {
global $default;

$value      = $default->user_change_server;
$desc_text  = 'Change Server';
$name       = 'user_change_server';
$desc       = 'User is able to choose a different IMAP server.';
include( './templates/setup/form_true_false_elem.inc' ); 

$value      = $default->user_change_folder;
$desc_text  = 'Change Folder';
$name       = 'user_change_folder';
$desc       = 'User is able to choose a different IMAP folder root.';
include( './templates/setup/form_true_false_elem.inc' ); 

$value      = $default->user_change_from;
$desc_text  = 'Change From';
$name       = 'user_change_from';
$desc       = 'User is able to change who the outbound mail is stamped as, don\'t use this if you don\'t trust your users to not forge mail.';
include( './templates/setup/form_true_false_elem.inc' );

$value      = $default->user_change_fullname;
$desc_text  = 'Change Fullname';
$name       = 'user_change_fullname';
$desc       = 'User is able to change outbound fullname e.g. John Smith.';
include( './templates/setup/form_true_false_elem.inc' ); 

$value      = $default->use_ldap_search;
$desc_text  = 'Use LDAP Search';
$name       = 'use_ldap_search';
$desc       = 'Seach for addresses using an LDAP server such as BigFoot.';
include( './templates/setup/form_true_false_elem.inc' );

$value      = $default->user_use_addressbook;
$desc_text  = 'Use addressbook';
$name       = 'user_use_addressbook';
$desc       = 'User is able to use the addressbook.';
include( './templates/setup/form_true_false_elem.inc' ); 
}

$form_subtitle = 'User abilities Configuration';
include( './templates/setup/stub_form.inc' );

?>
