<center>
<h3>IMP - ERROR : IMP IS CONFIGURABLE !!!</h3>
</center>

<p>
You IMP installation has been detected as being configurable from the web.
<P>
The only time that your IMP installation should be configurable if
your are wanting to use <A href="setup.php3">setup.php3</a>.
Otherwise your users could run the setup.php3 program themselves.
<P>
    To fix this you can run :
<ul>
   <li>chmod 000 (your imp dir)/setup.php3 (your imp dir)/lib/src/buildlib.php3
</ul>

</p>
