<?php
/*
The Actual calls to element includes and such are contained within
functions to prevent varaible collision in the main namespace.
*/
Function print_form() {
global $default;
$value      = $default->localhost;
$desc_text  = 'Local Server Name';                          /* desc_text */
$size       = 30;                                           /* size */
$name       = 'localhost';                                  /* elem name */
$desc       = 'The actual server name for this machine.';   /* Elem desc */
include( './templates/setup/form_text_elem.inc' ); 
}

$form_subtitle = 'Server Specific Configuration';
include( './templates/setup/stub_form.inc' );

?>
