<form action="<?php echo $default->root_url ?>/mailbox.php3" target="impmain" method="post" name="mboxSelect">
  <a href="javascript:document.mboxSelect.submit()"><img src="<?php echo $default->graphics_url ?>/open_folder.gif" border="0" width="16" height="16" align="middle" alt="<?php echo $lang->open_folder ?>"></a>
  <select name=mailbox onChange="document.mboxSelect.submit()">
    <?php echo $options ?>
  </select>
  <input type=hidden name=server value="<?php echo $server ?>">
</form>

</td></tr></table>
