<table border="0" align="center" width="95%" cellspacing="0" cellpadding="3">
<form method=post name="create">
<input type="hidden" name="actionID" value="<?php echo SUBSCRIBE_FOLDER ?>">

<tr bgcolor="<?php echo $default->dark_bg ?>">
  <td colspan="2" align="left">
    <?php $default->text_on_dark->start(); ?><b><?php echo $lang->subscribe_label ?></b></font>
  </td>
  <td align="right"><?php $help->link(FOLDERS_HELP_SUBSCRIBE, $help_file, 'imp') ?></td>
</tr>
<tr>
  <td align="right"><?php echo $lang->subscribe ?></td>
  <td colspan="2" align="left" bgcolor="<?php echo $default->item_bg ?>" width="100%">
  <select name="subscribe_mailbox"><?php echo "\n" . $newlist ?>
  </select>
</tr>
<tr><td colspan="3" align="center"><input type=submit value="<?php echo $lang->subscribe_button ?>"></td></tr>

</form>
</table>
