<tr bgcolor="<?php echo $default->nav_bg; ?>">
   <td><b><?php echo $desc_text; ?> :</b></td>
   <td>
   <select name="<?php echo( $name ); ?>">
   <?php
   if ( 
      ! is_array( $possible ) 
   && ! is_array( $possible_vals ) 
      ) {

   for( $xxxx = 0 ; $xxxx < count( $value ) ; $xxxx++ ) {
   echo( '<option value="' . $value[ $xxxx ] . '">' . $value[ $xxxx ] . "\n" );
   }

   } else {

   for( $xxxx = 0 ; $xxxx < count( $possible_vals ) ; $xxxx++ ) {
      $selected = '';
      if ( $value == $possible_vals[ $xxxx ] ) {
         $selected = ' selected ';
      }
      echo( '<option value="' . $possible_vals[ $xxxx ] .  '"' . $selected . '>' . $possible[ $xxxx ] . ' - [ ' . $possible_vals[ $xxxx ] . " ] \n" );
   }

   }
   ?>
   </select>
</tr>
<?php include( './templates/setup/form_elem_desc.inc' ); ?>
