/* Define all of the actions */
define("NO_ACTION",           0);
define("DELETE_MESSAGES",     1);
define("UNDELETE_MESSAGES",   2);
define("MOVE_MESSAGES",       3);
define("COPY_MESSAGES",       4);
define("EXPUNGE_MAILBOX",     5);
define("IMP_LOGIN",           6);
define("REPLY",               7);
define("REPLY_ALL",           8);
define("FORWARD",             9);
define("DELETE_FOLDER",      10);
define("CREATE_FOLDER",      11);
define("RENAME_FOLDER",      12);
define("DOWNLOAD_ATTACH",    13);
define("VIEW_ATTACH",        14);
define("DELETE_ADDR",        15);
define("ADD_ADDR",           16);
define("UPDATE_ADDR",        17);
define("UPDATE_PREFS",       18);
define("SEND_MESSAGE",       19);
define("POSTPONE_MESSAGE",   20);
define("VIEW_SOURCE",        21);
define("SAVE_MESSAGE",       22);
define("SUBSCRIBE_FOLDER",   23);
define("UNSUBSCRIBE_FOLDER", 24);
define("BOUNCE_MESSAGE",     25);
define("BOUNCE_COMPOSE",     26);
define("ADD_ATTACHMENT",     28);
define("DELETE_ATTACHMENT",  29);
define("MAILTO",             30);
define("ADD_CONTACT",        31);
define("IMP_SIGNUP",         32);

/* MENU Modes */
define("IMPMENU_DORMANT",  100 );
define("IMPMENU_MAIN",     200 );
define("IMPMENU_BLANK",    999 );

/* IMP CONFIGURATOR MODES */
define("IMPCFGMGR_WRITE_CONFIG", 800 );

/* -- Manager.php3 -- */
/* -- User Management -- */
define( "MGR_USER_ADD_FRM",             10100 );
define( "MGR_USER_EDIT_SELECT_FRM",     10200 );
define( "MGR_USER_EDIT_FRM",            10201 );
define( "MGR_USER_DELETE_SELECT_FRM",   10300 );
define( "MGR_USER_DELETE_CONFIRM_FRM",  10400 );

define( "MGR_USER_ADD",                 80100 );
define( "MGR_USER_EDIT",                80200 );


