<?php
/*
The Actual calls to element includes and such are contained within
functions to prevent varaible collision in the main namespace.
*/
Function print_form() {
global $default;

$value      = unserialize( urldecode( $default->path_to_sendmail ) );
$desc_text  = 'Sendmail';
$size       = 50;
$name       = 'path_to_sendmail';
$desc       = '';
if ( $value[ 0 ] != '[ NOT FOUND ]' && count( $value ) != 0 ) {
include( './templates/setup/form_multiselect_elem.inc' );
} else {
if ( $value[ 0 ] == '[ NOT FOUND ]' ) {
   $value = '[ NOT FOUND ]';
} else {
   $value = $default->path_to_sendmail;
}
include( './templates/setup/form_text_elem.inc' ); 
}


$value      = unserialize( urldecode( $default->path_to_ispell ) ) ;
$desc_text  = 'ISpell';
$size       = 50;
$name       = 'path_to_ispell';
$desc       = '';
if ( $value[ 0 ] != '[ NOT FOUND ]' && count( $value ) != 0 ) {
include( './templates/setup/form_multiselect_elem.inc' );
} else {
if ( $value[ 0 ] == '[ NOT FOUND ]' ) {
   $value = '[ NOT FOUND ]';
} else {
   $value = $default->path_to_ispell;
}
include( './templates/setup/form_text_elem.inc' ); 
}

$value      = unserialize( urldecode( $default->path_to_mswordview ) ) ;
$desc_text  = 'M$WordView';
$size       = 50;
$name       = 'path_to_mswordview';
$desc       = '';
if ( $value[ 0 ] != '[ NOT FOUND ]' && count( $value ) != 0 ) {
include( './templates/setup/form_multiselect_elem.inc' );
} else {
if ( $value[ 0 ] == '[ NOT FOUND ]' ) {
   $value = '[ NOT FOUND ]';
} else {
   $value = $default->path_to_mswordview;
}
include( './templates/setup/form_text_elem.inc' ); 
}

$value      = unserialize( urldecode( $default->path_to_tar ) ) ;
$desc_text  = 'GNU Tar';
$size       = 50;
$name       = 'path_to_tar';
$desc       = '';
if ( $value[ 0 ] != '[ NOT FOUND ]' && count( $value ) != 0 ) {
include( './templates/setup/form_multiselect_elem.inc' );
} else {
if ( $value[ 0 ] == '[ NOT FOUND ]' ) {
   $value = '[ NOT FOUND ]';
} else {
   $value = $default->path_to_tar;
}
include( './templates/setup/form_text_elem.inc' ); 
}

}

$form_subtitle = 'External Binaries Configuration';
include( './templates/setup/stub_form.inc' );


?>
