<?php
/*
The Actual calls to element includes and such are contained within
functions to prevent varaible collision in the main namespace.
*/
Function print_form() {
global $default;

$value      = '/horde/imp';
$desc_text  = 'Root Base Url';
$size       = 50;
$name       = 'root_url';
$desc       = 'Base url for imp i.e. /cvs/imp';
include( './templates/setup/form_text_elem.inc' ); 

$value      = '/horde/imp/graphics';
$desc_text  = 'Graphics Base Url';
$size       = 50;
$name       = 'graphics_url';
$desc       = 'Base url for imp\'s graphics i.e. /cvs/imp/graphics ';
include( './templates/setup/form_text_elem.inc' ); 


$value      = './templates';

}

$form_subtitle = 'Web Server Configuration';
include( './templates/setup/stub_form.inc' );

?>
