#!/bin/sh

MY_WEBOWNER="nobody.nobody"

chown $(MY_WEBOWNER) config/defaults.php3
chown $(MY_WEBOWNER) ../lib/horde.lib
chown $(MY_WEBOWNER) lib/db.lib
chown $(MY_WEBOWNER) lib/imp.lib
chown $(MY_WEBOWNER) lib/mime.lib
chown $(MY_WEBOWNER) lib/mimetypes.lib

chmod 500 config/defaults.php3
chmod 500 ../lib/horde.lib
chmod 500 lib/db.lib
chmod 500 lib/imp.lib
chmod 500 lib/mime.lib
chmod 500 lib/mimetypes.lib

chmod 000 setup.php3

echo 
echo I have made your configuration files, and libraries mode 0555
echo which is read / execute for everyone.
echo
echo And the setup.php3 is mode 0000 which is no access period.
echo 
echo 
