<html>
<head>
<title> w e l c o m e  t o  I M P </title>

<script language="JavaScript">
<!--
if (parent.impmenu)     { parent.impmenu.location="menu.php3"; }
if (parent.impfolder)   { parent.impfolder.location="menu.php3?menu=<?php echo IMPMENU_BLANK; ?>"; }
//-->
</script>

</head>

<?php $default->body->generate_body(); ?>

<noscript>
<p><b>IMP requires JavaScript to perform certain message handling functions</b></p>
</noscript>

<table border=0 width="100%"><tr><td align=center>
<table border=0 width="400"><tr><td align=center>

<form action="mailbox.php3" method="post">
<input type="hidden" name="actionID" value="<?php echo IMP_LOGIN ?>">
<input type="hidden" name="mailbox" value="INBOX">

<table border=0>
<tr>
  <td align="center" colspan="3">
  <font size="+1" face="<?php echo $default->font->face; ?>">
  I m a p &nbsp;&nbsp; w e b M a i l &nbsp;&nbsp; P r o g r a m
  </font></p>
  <p><font size=2 face="<?php echo $default->font->face; ?>">
  <?php echo $lang->$reason ?>
  </font></p>
  </td>
</tr>


<?php if ($default->user_change_server) : ?>
<tr><td align=right>Server:</td><td><input type="text" tabindex="1" name="server"></td><td><font size=2 face="<?php echo $default->font->face; ?>">[ default: <? echo $default->server; ?> ]</font></td></tr>
<?php endif; ?>

<?php if ($default->user_change_folder) : ?>
<tr><td align=right>Folders:</td><td><input type="text" tabindex="1" name="folders"></td><td><font size=2 face="<?php echo $default->font->face; ?>">[ default: <? echo $default->folders; ?> ]</font></td></tr>
<?php endif; ?>

<tr><td>&nbsp;</td><td align=center><input type="submit" tabindex="2" value="  log in  "></td></tr>

</table>
</form>

<?php if ($default->user_change_folder) : ?>
<p><font size=2 face="<?php echo $default->font->face; ?>">Note: "Folders" is where your mail folders live, <b><i>relative to your home directory.</i></b> If your folders are in $HOME/Mail/, then all you need to enter is Mail/ for "Folders" (remember that unix is case-sensitive).</font></p>
<?php endif; ?>

</td></tr></table>
</td></tr></table>

</body>
</html>
