<input type=hidden name=mailbox value="<?php echo $mailbox ?>">
<input type=hidden name=page value="<?php echo $page ?>">
<input type=hidden name=actionID value="">
<input type=hidden name=targetMbox value="">
