<script language="JavaScript">
<!--
    if ( parent.impmenu ) {
		parent.impmenu.location		= "menu.php3?menu=<?php echo IMPMENU_MAIN ?>";
	}
	if ( parent.impfolder ) {
		parent.impfolder.location	= "select.php3";
	}
//-->
</script>
