<p>
   <b>
IMP needs Netscape Navigator 3.0, Internet Explorer 3.0 or better.
   </b>
</p>

<hr>

<p>
You have recived this screen due to a unrecognized web browser.<br>
Please send a copy of this output below to :<br>
<center>( cvs@horde.org, and zerodiv@atcjet.net )</center><br>
HTTP_USER_AGENT : <?php echo( $HTTP_USER_AGENT ); ?>
