<table border="0" width="100%">
<tr>

<td valign="top">
  <?php if (!isset($status) || ($status == '')) $status = 'green'; ?>
  <img src="<?php echo "$default->graphics_url/$status.gif" ?>">
</td>

<td valign="top" align="left">
<b><font face="<?php echo $default->text_on_dark->face; ?>" color="<?php echo $default->text_on_dark->color; ?>" size="2">

<?php
  if (isset($message) && ($message)) echo $message;
  else echo $lang->login_msg;
?>

</font></b>
</td>

<td align="right" valign="top">
<b><a href="http://horde.org/imp/" target="_blank"><font face="<?php echo $default->font->face; ?>" size="2">IMP, Version <?php echo IMP_VERSION ?></font></a></b>
</td>

</tr>
</table>
