<TR BGCOLOR="<?php echo $default->item_bg; ?>">
<TD>
<PRE>
<?php

Function print_imp_sect( $imp_sect )
   {
   echo( "\n" );
   echo( "/* ------------------------------------------------------------ */\n" );
   echo( '/* ' . $imp_sect . '*/' . "\n" );
   }

Function print_imp_doc( $imp_doc, $obj_root )
   {
   print_imp( $obj_root . '->bg_color',   'html_' . $imp_doc . '_bg_color',      'Background color.' );
   print_imp( $obj_root . '->bg_file',    'html_' . $imp_doc . '_bg_file',       'Background file.' );
   print_imp( $obj_root . '->text_color', 'html_' . $imp_doc . '_text_color',    'Text color.' );
   print_imp( $obj_root . '->link_color', 'html_' . $imp_doc . '_link_color',    'HyperLink color.' );
   print_imp( $obj_root . '->vlink_color', 'html_' . $imp_doc . '_vlink_color',  'Visited HyperLink color.' );
   print_imp( $obj_root . '->alink_color', 'html_' . $imp_doc . '_alink_color',  'Active HyperLink color.' );
   }

Function print_imp( $imp_var, $imp_val, $imp_desc )
   {
   echo( "\n" );
   printf( "%30s", ( '/* ' . $imp_desc . '*/' ) );
   echo( "\n" );
   printf( "%30s", $imp_var );
   echo( ' = ' );
   if ( strlen( $imp_val ) > 30 )
      {
      echo( "'" . $imp_val . "'" );
      } else {
      printf( "%30s", ( "'" . $imp_val . "';" ) );
      }
   echo( "\n" );
   }

echo( '
&lt?php

/*
================================================================================
- IMP Configuration File -

Generated by Imp Configurator

Imp configurator by : Zer0DiVide

Copy this text and place it in your :
 ( Imp installation root )/config/defaults.php3

This should be the only text in that file.
================================================================================
*/
');

/* LOCAL Configuration */
print_imp_sect( 'LOCAL Configuration' );
print_imp( '$default->localhost',      $localhost,          "Local host name" );

/* URL Configuration */
print_imp_sect( 'URL Configuration' );
print_imp( '$default->root_url',             $root_url,                 "Root Url" );
print_imp( '$default->graphics_url',         $graphics_url,             "Graphics Url" );

/* IMAP Configuration */
print_imp_sect( 'IMAP Configuration' );
print_imp( '$default->server',               $imap_server,              "Default Imap Server" );
print_imp( '$default->folders',              $imap_folders,             "Default Root Imap Folder" );
print_imp( '$default->secure',               $use_ssl_cookies,          "Use SSL for cookies if it is a secure connection. " );

/* USER Configuration */
print_imp_sect( 'USER Configuration' );
print_imp(
   '$default->user_change_server', 
   $user_change_server,
   'User change server.'
   );
print_imp( '$default->user_change_folder',   $user_change_folder,       'User change folder.' );

/* IMP Configuration */
print_imp_sect( 'Imp Configuration' );
print_imp( '$default->max_messages_page',    $imp_max_messages_page,    'Max messages per page.' );

/* HTML Configuration - Themes Configuration */
print_imp_sect( 'HTML Configuration - Themes Configuration' );
print_imp( '$default->dark_bg',              $html_theme_dark_bg,       'Dark cell background.' );
print_imp( '$default->light_bg',             $html_theme_light_bg,      'Light cell background.' );
print_imp( '$default->text_on_light',        $html_theme_text_on_light, 'Text on light background.' );
print_imp( '$default->text_on_dark',         $html_theme_text_on_dark,  'Text on dark.' );
print_imp( '$default->text_bg',              $html_theme_text_bg,       'Text background.' );
print_imp( '$default->item_bg',              $html_theme_item_bg,       'Item background.' );
print_imp( '$default->nav_bg',               $html_theme_nav_bg,        'Navigational background.' );

/* DOC Body Config */
print_imp_sect( 'HTML Configuration - Global Configuration' );
print_imp_sect( 'HTML Configuration - Global Configuration - Right Frame - Body Attributes' );
print_imp_doc( 'body', '$default->body' );
print_imp_sect( 'HTML Configuration - Global Configuration - Left Frame - Body Attributes' );
print_imp_doc( 'impmenu', '$default->sidebar' );

echo( "\n" );
echo( "/* ------------------------------------------------------------ */\n" );
echo( '/* EOF */' . "\n" );
echo( '?&gt' . "\n" );

?>
</PRE>
</TD>
</TR>
</Table>
</body>
</html>
