<center>
<b>- IMP MENU -</b>
<br>
<?php if ($menu == IMPMENU_DORMANT): ?>
<a href="login.php3?reason=login"><?php echo $lang->login; ?></a>

<?php elseif ($menu == IMPMENU_MAIN): ?>
<?php if (($default->user_use_addressbook == true) && $default->use_db): ?>
  
<a href="contacts.php3">[ Contacts ]</a>

<?php endif; ?>

<a href="mailbox.php3">[ <?php echo $lang->check_inbox ?> ]</a>

<a href="compose.php3">[ <?php echo $lang->compose ?> ]</a>
<a href="folders.php3">[ <?php echo $lang->folders ?> ]</a>


<?php if ($default->use_db): ?>
<a href="prefs.php3">[ <?php echo $lang->prefs ?> ]</a>
<?php endif; ?>

<?php if ($default->v2_database) {
   echo '<p>Horde Management';
   manager_menu_item(MGR_USER_ADD_FRM, 'Add User');
   manager_menu_item(MGR_USER_EDIT_SELECT_FRM, 'Edit User');
   manager_menu_item(MGR_USER_DELETE_SELECT_FRM, 'Delete User');
}
?>

<?php endif; ?>

<a href="<?php echo $default->faq_url ?>">[ <?php echo $lang->faq ?> ]</a>

<?php if ($menu == IMPMENU_MAIN): ?>
<br>
<a href="login.php3?reason=logout">[ <?php echo $lang->logout ?> ]</a>
<?php endif; ?>
</center>

<?php
// FIXME : Build ldap support
?>
<hr>
