<script language="JavaScript">
<!--
function open_help_win (win_location) {
   var screen_width, screen_height;
   var win_top, win_left;
   var HelpWin;
   
   screen_height        = 0;     screen_width      = 0;
   win_top              = 0;     win_left          = 0;
   
   var help_win_width   = <?php echo $this->help_win_width ?>;
   var help_win_height  = <?php echo $this->help_win_height ?>;
   
   if (window.innerWidth) screen_width = window.innerWidth;
   if (window.innerHeight) screen_height = window.innerHeight;
   
   win_top  = screen_height - help_win_height - 20;
   win_left = screen_width  - help_win_width  - 20;
   HelpWin  = window.open(
               win_location,
               'HordeHelpWin',
               'width='+help_win_width+',height='+help_win_height+',top='+win_top+',left='+win_left
   );
   HelpWin.focus();
}

function close_help_win() {
   document.all[ 'HordeHelpWin' ].close();
}

//-->
</script>
