<?php
/*
edit_user_results.inc
$version$
$author$
*/
$EditUser = new HordeUser;
$EditUser->user_id            = $horde_user_id;
$EditUser->user_name          = $horde_user_name;
$EditUser->user_password      = $horde_user_password;
$EditUser->login_deny         = $horde_login_deny;


list( $good, $ret_val, $reason ) = $db->User->Modify( $EditUser->user_id, $EditUser );

echo( '<center>' );
echo( '<table bgcolor="' . $default->nav_bg . '" border="0" cellspacing="0">' );
echo( "\n" );
$horde_config_frm = new HordeConfigForm;
$horde_config_frm->full_colspan = 2;
$horde_config_frm->gen_title_bar( 'Edit User' );
$stat_code = '';
if ( $good == true ) {
$stat_code =
'<img src="' . $default->graphics_url . '/green.gif">' .
'Account Succesfully edited.';
} else {
$stat_code =
'<img src="' . $default->graphics_url . '/red.gif"><b>' .
$reason . '</b>' .
'<img src="' . $default->graphics_url . '/red.gif"><b>';
}
$horde_config_frm->gen_sect_subtitle( 'Account Edit status : <br><center>' . $stat_code . '</center>' );
$horde_config_frm->gen_attr_value_title();
echo( '<tr bgcolor="' . $default->light_bg . '">' );
$horde_config_frm->gen_single_item( '<b>User Name:</b>' );
$horde_config_frm->gen_single_item( $EditUser->user_name );
echo( '</tr>' );
echo( '<tr bgcolor="' . $default->light_bg . '">' );
$horde_config_frm->gen_single_item( '<b>Password:</b>' );
$horde_config_frm->gen_single_item( $EditUser->user_password );
echo( '</tr>' );
echo( '<tr bgcolor="' . $default->light_bg . '">' );
$horde_config_frm->gen_single_item( '<b>Login Deny:</b>' );
if ( $horde_login_deny == true ) {
$horde_config_frm->gen_single_item( 'True' );
} else {
$horde_config_frm->gen_single_item( 'False' );
}
echo( '</tr>' );
/* Allow them to edit their input */
if ( $good != true ) {
$title                  = 'Edit Horde User';
$subtitle               =
'This form allows you to edit a horde user';
$action_url             = 'manager.php3';
$action_tag             = MGR_USER_EDIT;
require( "$default->include_dir/manager/user_attributes.inc" );
}
echo( '</table>' );
echo( '</center>' );
?>
