<?php

/*
 
 File: config/lang.php3
 $Author: rkrusty $
 $Revision: 1.15 $
 $Date: 1999/04/03 03:38:35 $
 
 IMP: Copywrite 1998 Charles J. Hagenbuch chuck@horde.org
 
 This code is under the GNU Public License
 See the file COPYING in this directory
 
 */

$default->lang['cs'] = 'Czech';
$default->lang['da'] = 'Danish';
$default->lang['de'] = 'German';
$default->lang['en'] = 'English';
$default->lang['es'] = 'Spanish';
$default->lang['fr'] = 'French';
$default->lang['nl'] = 'Dutch';
$default->lang['nl-BE'] = 'Belgium Dutch';
$default->lang['no'] = 'Norwegian';
$default->lang['pt-BR'] = 'Brazilian Portuguese';
$default->lang['ru'] = 'Russian';
$default->lang['sk'] = 'Slovak';
$default->lang['sv'] = 'Swedish';

# multi-language spelling support
$default->ispell_lang['en'] = '';
$default->ispell_lang['fr'] = '-d francais';

?>
