-- script to create the necessary Informix database and tables
-- you can simply run this file in dbacces

-- change the database and table names to whatever you'd like
-- them to be - just make sure the IMP config matches.

-- create the database
CREATE DATABASE imp;

-- now connect to the new database
database imp;

-- create the address table
CREATE TABLE imp_addr (
  user text,
  address text,
  nickname text,
  fullname text
);

-- now create the pref table
CREATE TABLE imp_pref (
  user text,
  sig text,
  replyto text,
  fullname text
);

-- done!
