/*
   File: lib/db/mysql.lib.php3
   $Author: jon $
   $Revision: 1.1 $
   $Date: 1999/03/29 20:32:38 $

   IMP : Copyright 1998 Charles J. Hagenbuch chuck@osmos.ml.org

   This code is under the GNU Public License
   See the file COPYING in this directory

File Purpose:
This file contains the support for textrc-based preferences.

*/
