<?php
   if (isset($page_count)) {
      echo '<b> - [ ' . $lang->pagenav($page, $page_count) . ' ]</b>';
      echo '<br>';
      echo '</center>';
      echo '<center>';
      echo $pages_first    . ' ';
      echo $pages_prev     . ' ';
      echo $pages_next     . ' ';
      echo $pages_last;
      echo '<br>';
   }
?>
<a href="javascript:Submit(<?php echo DELETE_MESSAGES ?>)"><?php
   echo '[ ' . $lang->selected_mail . ' ' . $lang->delete_link . ' ]';
?></a>
<a href="javascript:Submit(<?php echo UNDELETE_MESSAGES ?>)"><?php
echo '[ ' . $lang->selected_mail . ' ' . $lang->undelete_link . ' ]'; 
?></a>
</center>
 
  
<form method="post" name="pagenav1">
  <input type="hidden" name="mailbox" value="<?php echo $mailbox ?>">
</form>

<b>Selected Message Actions :</b><br>
<br>
<form method="post" name="messages">
<center>
   <input type="submit" value="<?php echo $lang->delete_link; ?>">
   <input type="submit" value="<?php echo $lang->undelete_link; ?>">
   <input type="submit" value="<?php echo $lang->move_link; ?>">
   <input type="submit" value="<?php echo $lang->copy_link; ?>">
   <select name="target1">
   <?php echo $options ?>
   </select>

<?php
/*
Thers's got to be a way to select all / delete all etc....
*/
?>
<a href="mailbox.php3?actionID=<?php echo EXPUNGE_MAILBOX ?>&mailbox=<?php echo urlencode($mailbox) ?>"><?php echo $lang->empty_trash ?></a>
</center>
