<tr bgcolor="<?php echo $default->nav_bg; ?>">
   <td><b><?php echo $desc_text; ?> :</b></td>
   <td><input type="text" size="<?php echo $size; ?>" name="<?php echo $name; ?>" value="<?php echo $value; ?>"></td>
</tr>
<?php include( './templates/setup/form_elem_desc.inc' ); ?>
